badwing.characters.skeleton package
===================================

Submodules
----------

badwing.characters.skeleton.brain module
----------------------------------------

.. automodule:: badwing.characters.skeleton.brain
   :members:
   :undoc-members:
   :show-inheritance:

badwing.characters.skeleton.skeleton module
-------------------------------------------

.. automodule:: badwing.characters.skeleton.skeleton
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.characters.skeleton
   :members:
   :undoc-members:
   :show-inheritance:
